@@ -28,9 +28,9 @@
 extern "C" {
 #endif
 
-/* 
+/*
  * p225-226 Chapter 7.6 in TS 29.274 V15.9.0
- * 
+ *
  * A Sequence Number used for a Command message shall have the most significant
  * bit set to 1. A Sequence Number in a message, which was triggered by
  * a Command message, as well as respective Triggered Reply message
@@ -54,10 +54,10 @@ extern "C" {
 typedef struct ogs_gtp_xact_s {
     ogs_lnode_t     node;           /**< A node of list */
     ogs_index_t     index;
-    
+
 #define OGS_GTP_LOCAL_ORIGINATOR  0
 #define OGS_GTP_REMOTE_ORIGINATOR 1
-    uint8_t         org;            /**< Transaction' originator. 
+    uint8_t         org;            /**< Transaction' originator.
                                          local or remote */
 
     uint32_t        xid;            /**< Transaction ID */
@@ -67,8 +67,8 @@ typedef struct ogs_gtp_xact_s {
     void            *data;          /**< Transaction Data */
 
     int             step;           /**< Current step in the sequence.
-                                         1 : Initial 
-                                         2 : Triggered 
+                                         1 : Initial
+                                         2 : Triggered
                                          3 : Triggered-Reply */
     struct {
         uint8_t     type;           /**< Message type history */
@@ -111,23 +111,17 @@ void ogs_gtp_xact_final(void);
 ogs_gtp_xact_t *ogs_gtp_xact_local_create(ogs_gtp_node_t *gnode,
         ogs_gtp_header_t *hdesc, ogs_pkbuf_t *pkbuf,
         void (*cb)(ogs_gtp_xact_t *xact, void *data), void *data);
-ogs_gtp_xact_t *ogs_gtp_xact_remote_create(
-        ogs_gtp_node_t *gnode, uint32_t sqn);
 ogs_gtp_xact_t *ogs_gtp_xact_cycle(ogs_gtp_xact_t *xact);
 void ogs_gtp_xact_delete_all(ogs_gtp_node_t *gnode);
 
 int ogs_gtp_xact_update_tx(ogs_gtp_xact_t *xact,
         ogs_gtp_header_t *hdesc, ogs_pkbuf_t *pkbuf);
-int ogs_gtp_xact_update_rx(ogs_gtp_xact_t *xact, uint8_t type);
 
 int ogs_gtp_xact_commit(ogs_gtp_xact_t *xact);
 
 int ogs_gtp_xact_receive(ogs_gtp_node_t *gnode,
         ogs_gtp_header_t *h, ogs_gtp_xact_t **xact);
 
-ogs_gtp_xact_t *ogs_gtp_xact_find(ogs_index_t index);
-ogs_gtp_xact_t *ogs_gtp_xact_find_by_xid(
-        ogs_gtp_node_t *gnode, uint8_t type, uint32_t xid);
 void ogs_gtp_xact_associate(ogs_gtp_xact_t *xact1, ogs_gtp_xact_t *xact2);
 void ogs_gtp_xact_deassociate(ogs_gtp_xact_t *xact1, ogs_gtp_xact_t *xact2);
 
