@@ -28,13 +28,13 @@ type_list["Header compression configuration"]["encode"] = \
 
 type_list["DNN"]["decode"] = \
 "    {\n" \
-"        char data_network_name[OGS_MAX_DNN_LEN];\n" \
+"        char data_network_name[OGS_MAX_DNN_LEN+1];\n" \
 "        dnn->length = ogs_fqdn_parse(data_network_name, dnn->value, ogs_min(dnn->length, OGS_MAX_DNN_LEN+1));\n" \
 "        if (dnn->length > 0) {\n" \
-"            ogs_cpystrn(dnn->value, data_network_name, ogs_min(dnn->length, OGS_MAX_DNN_LEN) + 1);\n" \
-"         } else {\n" \
-"             ogs_error(\"UE not APN setting\");\n" \
-"         }\n" \
+"            ogs_cpystrn(dnn->value, data_network_name, ogs_min(dnn->length, OGS_MAX_DNN_LEN)+1);\n" \
+"        } else {\n" \
+"            ogs_error(\"UE not APN setting\");\n" \
+"        }\n" \
 "    }\n\n"
 
 type_list["DNN"]["encode"] = \
