@@ -1,7 +1,7 @@
 /*
  * amf_event_area.h
  *
- *
+ * 
  */
 
 #ifndef _OpenAPI_amf_event_area_H_
@@ -14,6 +14,7 @@
 #include "../include/binary.h"
 #include "ladn_info.h"
 #include "presence_info.h"
+#include "snssai.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -23,12 +24,16 @@ typedef struct OpenAPI_amf_event_area_s OpenAPI_amf_event_area_t;
 typedef struct OpenAPI_amf_event_area_s {
     struct OpenAPI_presence_info_s *presence_info;
     struct OpenAPI_ladn_info_s *ladn_info;
+    struct OpenAPI_snssai_s *s_nssai;
+    char *nsi_id;
 } OpenAPI_amf_event_area_t;
 
 OpenAPI_amf_event_area_t *OpenAPI_amf_event_area_create(
     OpenAPI_presence_info_t *presence_info,
-    OpenAPI_ladn_info_t *ladn_info
-    );
+    OpenAPI_ladn_info_t *ladn_info,
+    OpenAPI_snssai_t *s_nssai,
+    char *nsi_id
+);
 void OpenAPI_amf_event_area_free(OpenAPI_amf_event_area_t *amf_event_area);
 OpenAPI_amf_event_area_t *OpenAPI_amf_event_area_parseFromJSON(cJSON *amf_event_areaJSON);
 cJSON *OpenAPI_amf_event_area_convertToJSON(OpenAPI_amf_event_area_t *amf_event_area);
