@@ -26,10 +26,9 @@ OpenAPI_app_session_context_update_data_t *OpenAPI_app_session_context_update_da
     OpenAPI_list_t *tsn_port_man_cont_nwtts
 )
 {
-    OpenAPI_app_session_context_update_data_t *app_session_context_update_data_local_var = OpenAPI_malloc(sizeof(OpenAPI_app_session_context_update_data_t));
-    if (!app_session_context_update_data_local_var) {
-        return NULL;
-    }
+    OpenAPI_app_session_context_update_data_t *app_session_context_update_data_local_var = ogs_malloc(sizeof(OpenAPI_app_session_context_update_data_t));
+    ogs_assert(app_session_context_update_data_local_var);
+
     app_session_context_update_data_local_var->af_app_id = af_app_id;
     app_session_context_update_data_local_var->af_rout_req = af_rout_req;
     app_session_context_update_data_local_var->asp_id = asp_id;
@@ -68,6 +67,7 @@ void OpenAPI_app_session_context_update_data_free(OpenAPI_app_session_context_up
     ogs_free(app_session_context_update_data->mc_video_id);
     OpenAPI_list_for_each(app_session_context_update_data->med_components, node) {
         OpenAPI_map_t *localKeyValue = (OpenAPI_map_t*)node->data;
+        ogs_free(localKeyValue->key);
         OpenAPI_media_component_rm_free(localKeyValue->value);
         ogs_free(localKeyValue);
     }
@@ -368,9 +368,9 @@ OpenAPI_app_session_context_update_data_t *OpenAPI_app_session_context_update_da
         cJSON *localMapObject = med_components_local_map;
         if (cJSON_IsObject(med_components_local_map)) {
             localMapKeyPair = OpenAPI_map_create(
-                localMapObject->string, OpenAPI_media_component_rm_parseFromJSON(localMapObject));
+                ogs_strdup(localMapObject->string), OpenAPI_media_component_rm_parseFromJSON(localMapObject));
         } else if (cJSON_IsNull(med_components_local_map)) {
-            localMapKeyPair = OpenAPI_map_create(localMapObject->string, NULL);
+            localMapKeyPair = OpenAPI_map_create(ogs_strdup(localMapObject->string), NULL);
         } else {
             ogs_error("OpenAPI_app_session_context_update_data_parseFromJSON() failed [med_components]");
             goto end;
@@ -495,21 +495,21 @@ OpenAPI_app_session_context_update_data_t *OpenAPI_app_session_context_update_da
     }
 
     app_session_context_update_data_local_var = OpenAPI_app_session_context_update_data_create (
-        af_app_id ? ogs_strdup_or_assert(af_app_id->valuestring) : NULL,
+        af_app_id ? ogs_strdup(af_app_id->valuestring) : NULL,
         af_rout_req ? af_rout_req_local_nonprim : NULL,
-        asp_id ? ogs_strdup_or_assert(asp_id->valuestring) : NULL,
-        bdt_ref_id ? ogs_strdup_or_assert(bdt_ref_id->valuestring) : NULL,
+        asp_id ? ogs_strdup(asp_id->valuestring) : NULL,
+        bdt_ref_id ? ogs_strdup(bdt_ref_id->valuestring) : NULL,
         ev_subsc ? ev_subsc_local_nonprim : NULL,
-        mcptt_id ? ogs_strdup_or_assert(mcptt_id->valuestring) : NULL,
-        mc_video_id ? ogs_strdup_or_assert(mc_video_id->valuestring) : NULL,
+        mcptt_id ? ogs_strdup(mcptt_id->valuestring) : NULL,
+        mc_video_id ? ogs_strdup(mc_video_id->valuestring) : NULL,
         med_components ? med_componentsList : NULL,
-        mps_id ? ogs_strdup_or_assert(mps_id->valuestring) : NULL,
-        mcs_id ? ogs_strdup_or_assert(mcs_id->valuestring) : NULL,
+        mps_id ? ogs_strdup(mps_id->valuestring) : NULL,
+        mcs_id ? ogs_strdup(mcs_id->valuestring) : NULL,
         preempt_control_info ? preempt_control_info_local_nonprim : NULL,
         res_prio ? res_prioVariable : 0,
         serv_inf_status ? serv_inf_statusVariable : 0,
         sip_fork_ind ? sip_fork_indVariable : 0,
-        spon_id ? ogs_strdup_or_assert(spon_id->valuestring) : NULL,
+        spon_id ? ogs_strdup(spon_id->valuestring) : NULL,
         spon_status ? spon_statusVariable : 0,
         tsn_bridge_man_cont ? tsn_bridge_man_cont_local_nonprim : NULL,
         tsn_port_man_cont_dstt ? tsn_port_man_cont_dstt_local_nonprim : NULL,
