@@ -12,10 +12,9 @@ OpenAPI_emergency_info_t *OpenAPI_emergency_info_create(
     int epdg_ind
 )
 {
-    OpenAPI_emergency_info_t *emergency_info_local_var = OpenAPI_malloc(sizeof(OpenAPI_emergency_info_t));
-    if (!emergency_info_local_var) {
-        return NULL;
-    }
+    OpenAPI_emergency_info_t *emergency_info_local_var = ogs_malloc(sizeof(OpenAPI_emergency_info_t));
+    ogs_assert(emergency_info_local_var);
+
     emergency_info_local_var->pgw_fqdn = pgw_fqdn;
     emergency_info_local_var->pgw_ip_address = pgw_ip_address;
     emergency_info_local_var->smf_instance_id = smf_instance_id;
@@ -123,9 +122,9 @@ OpenAPI_emergency_info_t *OpenAPI_emergency_info_parseFromJSON(cJSON *emergency_
     }
 
     emergency_info_local_var = OpenAPI_emergency_info_create (
-        pgw_fqdn ? ogs_strdup_or_assert(pgw_fqdn->valuestring) : NULL,
+        pgw_fqdn ? ogs_strdup(pgw_fqdn->valuestring) : NULL,
         pgw_ip_address ? pgw_ip_address_local_nonprim : NULL,
-        smf_instance_id ? ogs_strdup_or_assert(smf_instance_id->valuestring) : NULL,
+        smf_instance_id ? ogs_strdup(smf_instance_id->valuestring) : NULL,
         epdg_ind ? true : false,
         epdg_ind ? epdg_ind->valueint : 0
     );
