@@ -35,10 +35,9 @@ OpenAPI_pcc_rule_t *OpenAPI_pcc_rule_create(
     int dis_ue_notif
 )
 {
-    OpenAPI_pcc_rule_t *pcc_rule_local_var = OpenAPI_malloc(sizeof(OpenAPI_pcc_rule_t));
-    if (!pcc_rule_local_var) {
-        return NULL;
-    }
+    OpenAPI_pcc_rule_t *pcc_rule_local_var = ogs_malloc(sizeof(OpenAPI_pcc_rule_t));
+    ogs_assert(pcc_rule_local_var);
+
     pcc_rule_local_var->flow_infos = flow_infos;
     pcc_rule_local_var->app_id = app_id;
     pcc_rule_local_var->app_descriptor = app_descriptor;
@@ -514,7 +513,7 @@ OpenAPI_pcc_rule_t *OpenAPI_pcc_rule_parseFromJSON(cJSON *pcc_ruleJSON)
         ogs_error("OpenAPI_pcc_rule_parseFromJSON() failed [ref_qos_data]");
         goto end;
     }
-    OpenAPI_list_add(ref_qos_dataList , ogs_strdup_or_assert(ref_qos_data_local->valuestring));
+    OpenAPI_list_add(ref_qos_dataList , ogs_strdup(ref_qos_data_local->valuestring));
     }
     }
 
@@ -534,7 +533,7 @@ OpenAPI_pcc_rule_t *OpenAPI_pcc_rule_parseFromJSON(cJSON *pcc_ruleJSON)
         ogs_error("OpenAPI_pcc_rule_parseFromJSON() failed [ref_alt_qos_params]");
         goto end;
     }
-    OpenAPI_list_add(ref_alt_qos_paramsList , ogs_strdup_or_assert(ref_alt_qos_params_local->valuestring));
+    OpenAPI_list_add(ref_alt_qos_paramsList , ogs_strdup(ref_alt_qos_params_local->valuestring));
     }
     }
 
@@ -554,7 +553,7 @@ OpenAPI_pcc_rule_t *OpenAPI_pcc_rule_parseFromJSON(cJSON *pcc_ruleJSON)
         ogs_error("OpenAPI_pcc_rule_parseFromJSON() failed [ref_tc_data]");
         goto end;
     }
-    OpenAPI_list_add(ref_tc_dataList , ogs_strdup_or_assert(ref_tc_data_local->valuestring));
+    OpenAPI_list_add(ref_tc_dataList , ogs_strdup(ref_tc_data_local->valuestring));
     }
     }
 
@@ -574,7 +573,7 @@ OpenAPI_pcc_rule_t *OpenAPI_pcc_rule_parseFromJSON(cJSON *pcc_ruleJSON)
         ogs_error("OpenAPI_pcc_rule_parseFromJSON() failed [ref_chg_data]");
         goto end;
     }
-    OpenAPI_list_add(ref_chg_dataList , ogs_strdup_or_assert(ref_chg_data_local->valuestring));
+    OpenAPI_list_add(ref_chg_dataList , ogs_strdup(ref_chg_data_local->valuestring));
     }
     }
 
@@ -594,7 +593,7 @@ OpenAPI_pcc_rule_t *OpenAPI_pcc_rule_parseFromJSON(cJSON *pcc_ruleJSON)
         ogs_error("OpenAPI_pcc_rule_parseFromJSON() failed [ref_chg_n3g_data]");
         goto end;
     }
-    OpenAPI_list_add(ref_chg_n3g_dataList , ogs_strdup_or_assert(ref_chg_n3g_data_local->valuestring));
+    OpenAPI_list_add(ref_chg_n3g_dataList , ogs_strdup(ref_chg_n3g_data_local->valuestring));
     }
     }
 
@@ -614,7 +613,7 @@ OpenAPI_pcc_rule_t *OpenAPI_pcc_rule_parseFromJSON(cJSON *pcc_ruleJSON)
         ogs_error("OpenAPI_pcc_rule_parseFromJSON() failed [ref_um_data]");
         goto end;
     }
-    OpenAPI_list_add(ref_um_dataList , ogs_strdup_or_assert(ref_um_data_local->valuestring));
+    OpenAPI_list_add(ref_um_dataList , ogs_strdup(ref_um_data_local->valuestring));
     }
     }
 
@@ -634,7 +633,7 @@ OpenAPI_pcc_rule_t *OpenAPI_pcc_rule_parseFromJSON(cJSON *pcc_ruleJSON)
         ogs_error("OpenAPI_pcc_rule_parseFromJSON() failed [ref_um_n3g_data]");
         goto end;
     }
-    OpenAPI_list_add(ref_um_n3g_dataList , ogs_strdup_or_assert(ref_um_n3g_data_local->valuestring));
+    OpenAPI_list_add(ref_um_n3g_dataList , ogs_strdup(ref_um_n3g_data_local->valuestring));
     }
     }
 
@@ -663,7 +662,7 @@ OpenAPI_pcc_rule_t *OpenAPI_pcc_rule_parseFromJSON(cJSON *pcc_ruleJSON)
         ogs_error("OpenAPI_pcc_rule_parseFromJSON() failed [ref_qos_mon]");
         goto end;
     }
-    OpenAPI_list_add(ref_qos_monList , ogs_strdup_or_assert(ref_qos_mon_local->valuestring));
+    OpenAPI_list_add(ref_qos_monList , ogs_strdup(ref_qos_mon_local->valuestring));
     }
     }
 
@@ -715,11 +714,11 @@ OpenAPI_pcc_rule_t *OpenAPI_pcc_rule_parseFromJSON(cJSON *pcc_ruleJSON)
 
     pcc_rule_local_var = OpenAPI_pcc_rule_create (
         flow_infos ? flow_infosList : NULL,
-        app_id ? ogs_strdup_or_assert(app_id->valuestring) : NULL,
+        app_id ? ogs_strdup(app_id->valuestring) : NULL,
         app_descriptor ? app_descriptor->valueint : 0,
         cont_ver ? true : false,
         cont_ver ? cont_ver->valuedouble : 0,
-        ogs_strdup_or_assert(pcc_rule_id->valuestring),
+        ogs_strdup(pcc_rule_id->valuestring),
         precedence ? true : false,
         precedence ? precedence->valuedouble : 0,
         af_sig_protocol ? af_sig_protocolVariable : 0,
@@ -732,7 +731,7 @@ OpenAPI_pcc_rule_t *OpenAPI_pcc_rule_parseFromJSON(cJSON *pcc_ruleJSON)
         ref_chg_n3g_data ? ref_chg_n3g_dataList : NULL,
         ref_um_data ? ref_um_dataList : NULL,
         ref_um_n3g_data ? ref_um_n3g_dataList : NULL,
-        ref_cond_data ? ogs_strdup_or_assert(ref_cond_data->valuestring) : NULL,
+        ref_cond_data ? ogs_strdup(ref_cond_data->valuestring) : NULL,
         ref_qos_mon ? ref_qos_monList : NULL,
         addr_preser_ind ? true : false,
         addr_preser_ind ? addr_preser_ind->valueint : 0,
