@@ -1,7 +1,7 @@
 /*
  * qos_flow_notify_item.h
  *
- *
+ * 
  */
 
 #ifndef _OpenAPI_qos_flow_notify_item_H_
@@ -22,16 +22,20 @@ typedef struct OpenAPI_qos_flow_notify_item_s OpenAPI_qos_flow_notify_item_t;
 typedef struct OpenAPI_qos_flow_notify_item_s {
     int qfi;
     OpenAPI_notification_cause_e notification_cause;
+    bool is_current_qos_profile_index;
     int current_qos_profile_index;
+    bool is_null_qo_s_profile_index;
     int null_qo_s_profile_index;
 } OpenAPI_qos_flow_notify_item_t;
 
 OpenAPI_qos_flow_notify_item_t *OpenAPI_qos_flow_notify_item_create(
     int qfi,
     OpenAPI_notification_cause_e notification_cause,
+    bool is_current_qos_profile_index,
     int current_qos_profile_index,
+    bool is_null_qo_s_profile_index,
     int null_qo_s_profile_index
-    );
+);
 void OpenAPI_qos_flow_notify_item_free(OpenAPI_qos_flow_notify_item_t *qos_flow_notify_item);
 OpenAPI_qos_flow_notify_item_t *OpenAPI_qos_flow_notify_item_parseFromJSON(cJSON *qos_flow_notify_itemJSON);
 cJSON *OpenAPI_qos_flow_notify_item_convertToJSON(OpenAPI_qos_flow_notify_item_t *qos_flow_notify_item);
