@@ -29,32 +29,32 @@ extern "C" {
 int mme_gtp_open(void);
 void mme_gtp_close(void);
 
-void mme_gtp_send_create_session_request(mme_sess_t *sess);
-void mme_gtp_send_modify_bearer_request(mme_bearer_t *bearer, int uli_presence);
-void mme_gtp_send_delete_session_request(mme_sess_t *sess, int action);
+int mme_gtp_send_create_session_request(mme_sess_t *sess);
+int mme_gtp_send_modify_bearer_request(mme_bearer_t *bearer, int uli_presence);
+int mme_gtp_send_delete_session_request(mme_sess_t *sess, int action);
 void mme_gtp_send_delete_all_sessions(mme_ue_t *mme_ue, int action);
-void mme_gtp_send_create_bearer_response(
+int mme_gtp_send_create_bearer_response(
         mme_bearer_t *bearer, uint8_t cause_value);
-void mme_gtp_send_update_bearer_response(
+int mme_gtp_send_update_bearer_response(
         mme_bearer_t *bearer, uint8_t cause_value);
-void mme_gtp_send_delete_bearer_response(
+int mme_gtp_send_delete_bearer_response(
         mme_bearer_t *bearer, uint8_t cause_value);
-void mme_gtp_send_release_access_bearers_request(mme_ue_t *mme_ue, int action);
+int mme_gtp_send_release_access_bearers_request(mme_ue_t *mme_ue, int action);
 void mme_gtp_send_release_all_ue_in_enb(mme_enb_t *enb, int action);
 
-void mme_gtp_send_downlink_data_notification_ack(
+int mme_gtp_send_downlink_data_notification_ack(
         mme_bearer_t *bearer, uint8_t cause_value);
 
-void mme_gtp_send_create_indirect_data_forwarding_tunnel_request(
+int mme_gtp_send_create_indirect_data_forwarding_tunnel_request(
         mme_ue_t *mme_ue);
-void mme_gtp_send_delete_indirect_data_forwarding_tunnel_request(
+int mme_gtp_send_delete_indirect_data_forwarding_tunnel_request(
         mme_ue_t *mme_ue, int action);
 
-void mme_gtp_send_bearer_resource_command(
+int mme_gtp_send_bearer_resource_command(
         mme_bearer_t *bearer, ogs_nas_eps_message_t *nas_message);
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* MME_S11_PATH_H */
+#endif /* MME_S11_PATH_H */
\ No newline at end of file
